==> qtjambi-xml-5.15.7-sources.jar: io/qt/xml/QXmlParseException.java <==
package io.qt.xml;


/**
 * <p>Used to report errors with the QXmlErrorHandler interface</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlparseexception.html">QXmlParseException</a></p>
 */
@Deprecated
public class QXmlParseException extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}
     *  with <code>s = ""</code>.</p>
     */
    public QXmlParseException(java.lang.String name, int c, int l, java.lang.String p) {
        this(name, c, l, p, "");
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>p = ""</code></li>
     * <li><code>s = ""</code></li>
     * </ul>
     */
    public QXmlParseException(java.lang.String name, int c, int l) {
        this(name, c, l, "", "");
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>l = -1</code></li>
     * <li><code>p = ""</code></li>
     * <li><code>s = ""</code></li>
     * </ul>
     */
    public QXmlParseException(java.lang.String name, int c) {
        this(name, c, (int)-1, "", "");
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>c = -1</code></li>
     * <li><code>l = -1</code></li>
     * <li><code>p = ""</code></li>
     * <li><code>s = ""</code></li>
     * </ul>
     */
    public QXmlParseException(java.lang.String name) {
        this(name, (int)-1, (int)-1, "", "");
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>name = ""</code></li>
     * <li><code>c = -1</code></li>
     * <li><code>l = -1</code></li>
     * <li><code>p = ""</code></li>
     * <li><code>s = ""</code></li>
     * </ul>
     */
    public QXmlParseException() {
        this("", (int)-1, (int)-1, "", "");
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#QXmlParseException">QXmlParseException::QXmlParseException(QString,int,int,QString,QString)</a></p>
     */
    public QXmlParseException(java.lang.String name, int c, int l, java.lang.String p, java.lang.String s){
        super((QPrivateConstructor)null);
        initialize_native(this, name, c, l, p, s);
    }
    
    private native static void initialize_native(QXmlParseException instance, java.lang.String name, int c, int l, java.lang.String p, java.lang.String s);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#QXmlParseException-1">QXmlParseException::QXmlParseException(QXmlParseException)</a></p>
     */
    public QXmlParseException(io.qt.xml.QXmlParseException other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlParseException instance, io.qt.xml.QXmlParseException other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#columnNumber">QXmlParseException::columnNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int columnNumber(){
        return columnNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int columnNumber_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#lineNumber">QXmlParseException::lineNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int lineNumber(){
        return lineNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int lineNumber_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#message">QXmlParseException::message()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String message(){
        return message_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String message_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#publicId">QXmlParseException::publicId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#systemId">QXmlParseException::systemId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlParseException(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlParseException clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlParseException clone_native(long __this_nativeId);
}

==> qtjambi-xml-5.15.10-sources.jar: io/qt/xml/QXmlParseException.java <==
package io.qt.xml;


/**
 * <p>Used to report errors with the QXmlErrorHandler interface</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlparseexception.html">QXmlParseException</a></p>
 */
@Deprecated
public class QXmlParseException extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}
     *  with <code>s = (String)null</code>.</p>
     */
    public QXmlParseException(java.lang.String name, int c, int l, java.lang.String p) {
        this(name, c, l, p, (String)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>p = (String)null</code></li>
     * <li><code>s = (String)null</code></li>
     * </ul>
     */
    public QXmlParseException(java.lang.String name, int c, int l) {
        this(name, c, l, (String)null, (String)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>l = -1</code></li>
     * <li><code>p = (String)null</code></li>
     * <li><code>s = (String)null</code></li>
     * </ul>
     */
    public QXmlParseException(java.lang.String name, int c) {
        this(name, c, (int)-1, (String)null, (String)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>c = -1</code></li>
     * <li><code>l = -1</code></li>
     * <li><code>p = (String)null</code></li>
     * <li><code>s = (String)null</code></li>
     * </ul>
     */
    public QXmlParseException(java.lang.String name) {
        this(name, (int)-1, (int)-1, (String)null, (String)null);
    }
    
    /**
     * <p>Overloaded constructor for {@link #QXmlParseException(java.lang.String, int, int, java.lang.String, java.lang.String)}</p>
     * <p>with: </p><ul>
     * <li><code>name = (String)null</code></li>
     * <li><code>c = -1</code></li>
     * <li><code>l = -1</code></li>
     * <li><code>p = (String)null</code></li>
     * <li><code>s = (String)null</code></li>
     * </ul>
     */
    public QXmlParseException() {
        this((String)null, (int)-1, (int)-1, (String)null, (String)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#QXmlParseException">QXmlParseException::QXmlParseException(QString,int,int,QString,QString)</a></p>
     */
    public QXmlParseException(java.lang.String name, int c, int l, java.lang.String p, java.lang.String s){
        super((QPrivateConstructor)null);
        initialize_native(this, name, c, l, p, s);
    }
    
    private native static void initialize_native(QXmlParseException instance, java.lang.String name, int c, int l, java.lang.String p, java.lang.String s);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#QXmlParseException-1">QXmlParseException::QXmlParseException(QXmlParseException)</a></p>
     */
    public QXmlParseException(io.qt.xml.QXmlParseException other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QXmlParseException instance, io.qt.xml.QXmlParseException other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#columnNumber">QXmlParseException::columnNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int columnNumber(){
        return columnNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int columnNumber_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#lineNumber">QXmlParseException::lineNumber()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int lineNumber(){
        return lineNumber_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int lineNumber_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#message">QXmlParseException::message()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String message(){
        return message_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String message_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#publicId">QXmlParseException::publicId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlparseexception.html#systemId">QXmlParseException::systemId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QXmlParseException(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QXmlParseException clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QXmlParseException clone_native(long __this_nativeId);
}
